@@ -3,7 +3,7 @@ from __future__ import absolute_import
 
 from django.test import TestCase
 from django.test.client import Client
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 
 TEST_URLS = [
     # (url, status_code, text_on_page)
@@ -16,9 +16,9 @@ class WorkingURLsTest(TestCase):
 
     def test_urls(self):
         """Visit each URL in turn"""
-        self.user = User.objects.create_user('john',
-                                             'john@montypython.com',
-                                             'password')
+        self.user = get_user_model().objects.create_user('john',
+                                                         'john@montypython.com',
+                                                         'password')
         self.user.is_staff = True
         self.user.save()
         self.client = Client()
